[mlpack-git] master: Deprecate old names; add new names. (1d7ea16)

gitdub at mlpack.org gitdub at mlpack.org
Mon Apr 18 16:08:08 EDT 2016


Repository : https://github.com/mlpack/mlpack
On branch  : master
Link       : https://github.com/mlpack/mlpack/compare/56b53a09e2d46b65f4d80560964487f1e193d345...64c049efa2df2661ce5b321a60c4178c3439d025

>---------------------------------------------------------------

commit 1d7ea164bb711c935c57fb266dc7cd9b77da7f1a
Author: Ryan Curtin <ryan at ratml.org>
Date:   Mon Apr 18 13:08:08 2016 -0700

    Deprecate old names; add new names.


>---------------------------------------------------------------

1d7ea164bb711c935c57fb266dc7cd9b77da7f1a
 src/mlpack/methods/neighbor_search/typedef.hpp | 24 ++++++++++++++++++++----
 1 file changed, 20 insertions(+), 4 deletions(-)

diff --git a/src/mlpack/methods/neighbor_search/typedef.hpp b/src/mlpack/methods/neighbor_search/typedef.hpp
index d0b8b38..1059e20 100644
--- a/src/mlpack/methods/neighbor_search/typedef.hpp
+++ b/src/mlpack/methods/neighbor_search/typedef.hpp
@@ -21,14 +21,30 @@ namespace mlpack {
 namespace neighbor {
 
 /**
- * The AllkNN class is the all-k-nearest-neighbors method.  It returns L2
- * distances (Euclidean distances) for each of the k nearest neighbors.
+ * The KNN class is the k-nearest-neighbors method.  It returns L2 distances
+ * (Euclidean distances) for each of the k nearest neighbors.
+ */
+typedef NeighborSearch<NearestNeighborSort, metric::EuclideanDistance> KNN;
+
+/**
+ * The KFN class is the k-furthest-neighbors method.  It returns L2 distances
+ * (Euclidean distances) for each of the k furthest neighbors.
+ */
+typedef NeighborSearch<FurthestNeighborSort, metric::EuclideanDistance> KFN;
+
+/**
+ * @deprecated
+ * The AllkNN class is the k-nearest-neighbors method.  It returns L2 distances
+ * (Euclidean distances) for each of the k nearest neighbors.  This typedef will
+ * be removed in mlpack 3.0.0; use the KNN typedef instead.
  */
 typedef NeighborSearch<NearestNeighborSort, metric::EuclideanDistance> AllkNN;
 
 /**
  * The AllkFN class is the all-k-furthest-neighbors method.  It returns L2
  * distances (Euclidean distances) for each of the k furthest neighbors.
  */
 typedef NeighborSearch<FurthestNeighborSort, metric::EuclideanDistance> AllkFN;
 
@@ -21,14 +21,30 @@ namespace mlpack {
 
 /**
- * The AllkFN class is the all-k-furthest-neighbors method.  It returns L2
- * distances (Euclidean distances) for each of the k furthest neighbors.
+ * @deprecated
+ * The AllkFN class is the k-furthest-neighbors method.  It returns L2
+ * distances (Euclidean distances) for each of the k furthest neighbors.  This
+ * typedef will be removed in mlpack 3.0.0; use the KFN typedef instead.
  */
 typedef NeighborSearch<FurthestNeighborSort, metric::EuclideanDistance> AllkFN;




More information about the mlpack-git mailing list